% This script makes plots corresponding to Figures 1 and 2 of "Atlantic
% Tropical Cyclones Downscaled from Climate Reanalyses Show Increasing
% Activity Through the Late 19th and 20th Centuries" 
% Note:  To calculate linear or Poisson regression lines, this script
% requires the MATLAB statistics and machine learning toolbox
%------------------------------------------------------------------------
region='USA';  % 'Atlantic', 'USA', or 'World' (case sensitive)
model='n20v2c'; % 'n20v2c', 'n20v3', or 'cera20c'
vble='ntc';    %  Options include total number of TCs with LMIs > 40kts (ntc),
               %  number of hurricanes (nhur), number of major hurricanes
               %  (nmajor), number of landfalling TCs (nland), total power
               %  dissipation index( pdi), and power dissipation index at
               %  landfall (pdiland). 
n=7;  % Number of years running average
reg_type='Poisson';  % Regression type, 'linear' or 'Poisson'
%--------------------------------------------------------------------------
nb=1;
%
%  Choose start point of historical record
%
if strcmpi(region,'Atlantic') || strcmpi(region, 'USA')
    nbest=1;
else
    if strcmpi(model,'cera20c') || strcmpi(model,'cera20c_b')
        nbest=80;
    else    
        nbest=130;
    end
end    
%
% Load time series variables
%
vblebst=[vble,'best'];
file=['time_series_files/',region,'_',lower(model)];
a=load(file);
x=a.x;
x2=a.x2;
y=a.(vblebst);
y2=a.(vble);
x(1:nbest-1)=[];y(1:nbest-1)=[];
pdilandbest=a.pdilandbest;
nlandbest=a.nlandbest;
ntcbest=a.ntcbest;
%
[~,qn]=size(y2);
%
% Calibrate to last 50 years of historical record
%
nbegsyn=max(qn-49,1);
if strcmpi(region,'Atlantic') || strcmpi(region,'USA')
    nbeg=max(qn-49,1);
else
    nbeg=1;
end    
cal=mean(y(nbeg:end))/mean(y2(nbegsyn:end));
%
%  Determine which variable to use to estimate sampling error
%
if floor(sum(y)) == sum(y)
    serr=y;
elseif y(end) == pdilandbest(end)
    serr=nlandbest;
else
    serr=ntcbest;
end    
m=floor((n-1)/2);
qx=max(size(x));
dum=serr;
for i=1+m:qx-m
    serr(i)=sum(dum(i-m:i+m));
end    
%
% Sampling error bounds (5% and 95%)
%
flow=poissinv(0.95,serr)./serr;
fhigh=poissinv(0.05,serr)./serr;
%
% Next, test to see if statistics toolbox present and if so, do regressions
%
V = ver;
VName = {V.Name};
if any(strcmp(VName, 'Statistics and Machine Learning Toolbox'))
    if strcmpi(reg_type,'linear')
        [bs,bintmit,statsmit]=regressm(runav(x2(nb:end),n),runav(cal*y2(nb:end),n));
        [bo,binto,statso]=regressm(runav(x,n),runav(y,n));
        %
        yfitmit=bs(1)+runav(x2(nb:end),n)*bs(2);
        yfito=bo(1)+runav(x,n)*bo(2);
    else
        [bs,devmit,stats]=glmfit(runav(x2(nb:end),n),runav(cal*y2(nb:end),n),'poisson','link','log');
        yfitmit = glmval(bs,runav(x2(nb:end),n),'log');
        statsmit(3)=stats.p(2);
        [bo,devo,stats]=glmfit(runav(x,n),runav(y,n),'poisson');
        yfito = glmval(bo,runav(x,n),'log');
        statso(3)=stats.p(2);
    end    
end
%
% Close any open figures and create new figure
%
close('all')
%
figure('position',[500,100,800,500])
%
clear errbar
%
% Find span of years of overlap between synthetic and historical tracks and
%   calculate confidence limits
%
[xtest,ia,ib]=intersect(x,x2(nb:end)); % Find span of years of overlap between synthetic and historical tracks
errbar(1,:)=runav(cal*y2(ib+nb-1).*(fhigh(ia+nb-1)-1),n);
errbar(2,:)=runav(cal*y2(ib+nb-1).*(1-flow(ia+nb-1)),n);
%
% Create plots with confidence limits
%
shadedErrorBar(runav(x2(ib+nb-1),n),runav(cal*y2(ib+nb-1),n),errbar,'r')
hold on
h=plot(runav(x,n),runav(y,n),'b',runav(x2(nb:end),n),cal*runav(y2(nb:end),n),'r','linewidth',1.5);
%
% Add regression curves of toolbox exists
%
if any(strcmp(VName, 'Statistics and Machine Learning Toolbox'))
    plot(runav(x,n),yfito,'--b',runav(x2(nb:end),n),yfitmit,'--r','linewidth',1.5);
end    
hold off
%
set(gca,'fontsize',14,'fontweight','bold')
xlabel('Year')
ylabel(vble)
tit=[region,', ',upper(model)];
title(tit)
legend(h,'IBTrACS','MIT Synthetic','location','best')
%
